from . import _Azure


class _Integration(_Azure):
    _type = "integration"
    _icon_dir = "resource_images/azure/integration"


class APIConnections(_Integration):
    _icon = "api-connections.png"


class APIForFhir(_Integration):
    _icon = "api-for-fhir.png"


class APIManagementServices(_Integration):
    _icon = "api-management-services.png"


class APIManagement(_Integration):
    _icon = "api-management.png"


class AppConfiguration(_Integration):
    _icon = "app-configuration.png"


class AzureAPIForFhir(_Integration):
    _icon = "azure-api-for-fhir.png"


class AzureDataCatalog(_Integration):
    _icon = "azure-data-catalog.png"


class AzureDataboxGateway(_Integration):
    _icon = "azure-databox-gateway.png"


class AzureServiceBus(_Integration):
    _icon = "azure-service-bus.png"


class AzureSQLServerStretchDatabases(_Integration):
    _icon = "azure-sql-server-stretch-databases.png"


class AzureStackEdge(_Integration):
    _icon = "azure-stack-edge.png"


class DataCatalog(_Integration):
    _icon = "data-catalog.png"


class DataFactories(_Integration):
    _icon = "data-factories.png"


class EventGridDomains(_Integration):
    _icon = "event-grid-domains.png"


class EventGridSubscriptions(_Integration):
    _icon = "event-grid-subscriptions.png"


class EventGridTopics(_Integration):
    _icon = "event-grid-topics.png"


class IntegrationAccounts(_Integration):
    _icon = "integration-accounts.png"


class IntegrationEnvironments(_Integration):
    _icon = "integration-environments.png"


class IntegrationServiceEnvironments(_Integration):
    _icon = "integration-service-environments.png"


class LogicAppsCustomConnector(_Integration):
    _icon = "logic-apps-custom-connector.png"


class LogicApps(_Integration):
    _icon = "logic-apps.png"


class PartnerNamespace(_Integration):
    _icon = "partner-namespace.png"


class PartnerRegistration(_Integration):
    _icon = "partner-registration.png"


class PartnerTopic(_Integration):
    _icon = "partner-topic.png"


class PowerPlatform(_Integration):
    _icon = "power-platform.png"


class Relays(_Integration):
    _icon = "relays.png"


class SendgridAccounts(_Integration):
    _icon = "sendgrid-accounts.png"


class ServiceBusRelays(_Integration):
    _icon = "service-bus-relays.png"


class ServiceBus(_Integration):
    _icon = "service-bus.png"


class ServiceCatalogManagedApplicationDefinitions(_Integration):
    _icon = "service-catalog-managed-application-definitions.png"


class SoftwareAsAService(_Integration):
    _icon = "software-as-a-service.png"


class SQLDataWarehouses(_Integration):
    _icon = "sql-data-warehouses.png"


class StorsimpleDeviceManagers(_Integration):
    _icon = "storsimple-device-managers.png"


class SystemTopic(_Integration):
    _icon = "system-topic.png"


# Aliases

# Terraform aliases
azurerm_api_management = APIManagementServices
azurerm_api_management_api = APIManagementServices
azurerm_app_configuration = AppConfiguration
azurerm_healthcare_service = AzureAPIForFhir
azurerm_data_catalog = DataCatalog
azurerm_data_factory = DataFactories
azurerm_eventgrid_domain = EventGridDomains
azurerm_eventgrid_event_subscription = EventGridSubscriptions
azurerm_eventgrid_topic = EventGridTopics
azurerm_logic_app_workflow = LogicApps
azurerm_logic_app_action_custom = LogicApps
azurerm_relay_namespace = Relays
azurerm_servicebus_namespace = ServiceBus
azurerm_servicebus_queue = ServiceBus
azurerm_servicebus_topic = ServiceBus
