from . import _Azure


class _Newicons(_Azure):
    _type = "newicons"
    _icon_dir = "resource_images/azure/newicons"


class AzureSustainability(_Newicons):
    _icon = "azure-sustainability.png"


class ConnectedVehiclePlatform(_Newicons):
    _icon = "connected-vehicle-platform.png"


class EntraConnectHealth(_Newicons):
    _icon = "entra-connect-health.png"


class EntraConnectSync(_Newicons):
    _icon = "entra-connect-sync.png"


class IcmTroubleshooting(_Newicons):
    _icon = "icm-troubleshooting.png"


class Osconfig(_Newicons):
    _icon = "osconfig.png"


class StorageActions(_Newicons):
    _icon = "storage-actions.png"


# Aliases
