from . import _Azure


class _Databases(_Azure):
    _type = "databases"
    _icon_dir = "resource_images/azure/database"


class AzureCosmosDb(_Databases):
    _icon = "azure-cosmos-db.png"


class AzureDataExplorerClusters(_Databases):
    _icon = "azure-data-explorer-clusters.png"


class AzureDatabaseMariadbServer(_Databases):
    _icon = "azure-database-mariadb-server.png"


class AzureDatabaseMigrationServices(_Databases):
    _icon = "azure-database-migration-services.png"


class AzureDatabaseMysqlServer(_Databases):
    _icon = "azure-database-mysql-server.png"


class AzureDatabasePostgresqlServerGroup(_Databases):
    _icon = "azure-database-postgresql-server-group.png"


class AzureDatabasePostgresqlServer(_Databases):
    _icon = "azure-database-postgresql-server.png"


class AzurePurviewAccounts(_Databases):
    _icon = "azure-purview-accounts.png"


class AzureSQLEdge(_Databases):
    _icon = "azure-sql-edge.png"


class AzureSQLServerStretchDatabases(_Databases):
    _icon = "azure-sql-server-stretch-databases.png"


class AzureSQLVM(_Databases):
    _icon = "azure-sql-vm.png"


class AzureSQL(_Databases):
    _icon = "azure-sql.png"


class AzureSynapseAnalytics(_Databases):
    _icon = "azure-synapse-analytics.png"


class CacheRedis(_Databases):
    _icon = "cache-redis.png"


class DataFactories(_Databases):
    _icon = "data-factories.png"


class ElasticJobAgents(_Databases):
    _icon = "elastic-job-agents.png"


class InstancePools(_Databases):
    _icon = "instance-pools.png"


class ManagedDatabase(_Databases):
    _icon = "managed-database.png"


class OracleDatabase(_Databases):
    _icon = "oracle-database.png"


class SQLDataWarehouses(_Databases):
    _icon = "sql-data-warehouses.png"


class SQLDatabase(_Databases):
    _icon = "sql-database.png"


class SQLElasticPools(_Databases):
    _icon = "sql-elastic-pools.png"


class SQLManagedInstance(_Databases):
    _icon = "sql-managed-instance.png"


class SQLServerRegistries(_Databases):
    _icon = "sql-server-registries.png"


class SQLServer(_Databases):
    _icon = "sql-server.png"


class SsisLiftAndShiftIr(_Databases):
    _icon = "ssis-lift-and-shift-ir.png"


class VirtualClusters(_Databases):
    _icon = "virtual-clusters.png"


# Aliases

# Terraform aliases
azurerm_cosmosdb_account = AzureCosmosDb
azurerm_kusto_cluster = AzureDataExplorerClusters
azurerm_mariadb_server = AzureDatabaseMariadbServer
azurerm_database_migration_service = AzureDatabaseMigrationServices
azurerm_mysql_server = AzureDatabaseMysqlServer
azurerm_mysql_flexible_server = AzureDatabaseMysqlServer
azurerm_postgresql_server = AzureDatabasePostgresqlServer
azurerm_postgresql_flexible_server = AzureDatabasePostgresqlServer
azurerm_mssql_server = SQLServer
azurerm_sql_server = SQLServer
azurerm_mssql_database = SQLDatabase
azurerm_sql_database = SQLDatabase
azurerm_mssql_elasticpool = SQLElasticPools
azurerm_mssql_managed_instance = SQLManagedInstance
azurerm_mssql_virtual_machine = AzureSQLVM
azurerm_synapse_workspace = AzureSynapseAnalytics
azurerm_redis_cache = CacheRedis
azurerm_data_factory = DataFactories
