from . import _Azure


class _Azurestack(_Azure):
    _type = "azurestack"
    _icon_dir = "resource_images/azure/azurestack"


class Capacity(_Azurestack):
    _icon = "capacity.png"


class InfrastructureBackup(_Azurestack):
    _icon = "infrastructure-backup.png"


class MultiTenancy(_Azurestack):
    _icon = "multi-tenancy.png"


class Offers(_Azurestack):
    _icon = "offers.png"


class Plans(_Azurestack):
    _icon = "plans.png"


class Updates(_Azurestack):
    _icon = "updates.png"


class UserSubscriptions(_Azurestack):
    _icon = "user-subscriptions.png"


# Aliases
