from . import _Azure


class _Networking(_Azure):
    _type = "networking"
    _icon_dir = "resource_images/azure/networking"


class ApplicationGateways(_Networking):
    _icon = "application-gateways.png"


class AtmMultistack(_Networking):
    _icon = "atm-multistack.png"


class AzureCommunicationsGateway(_Networking):
    _icon = "azure-communications-gateway.png"


class AzureFirewallManager(_Networking):
    _icon = "azure-firewall-manager.png"


class AzureFirewallPolicy(_Networking):
    _icon = "azure-firewall-policy.png"


class Bastions(_Networking):
    _icon = "bastions.png"


class CDNProfiles(_Networking):
    _icon = "cdn-profiles.png"


class ConnectedCache(_Networking):
    _icon = "connected-cache.png"


class Connections(_Networking):
    _icon = "connections.png"


class DDOSProtectionPlans(_Networking):
    _icon = "ddos-protection-plans.png"


class DNSMultistack(_Networking):
    _icon = "dns-multistack.png"


class DNSPrivateResolver(_Networking):
    _icon = "dns-private-resolver.png"


class DNSSecurityPolicy(_Networking):
    _icon = "dns-security-policy.png"


class DNSZones(_Networking):
    _icon = "dns-zones.png"


class ExpressrouteCircuits(_Networking):
    _icon = "expressroute-circuits.png"


class Firewalls(_Networking):
    _icon = "firewalls.png"


class FrontDoorAndCDNProfiles(_Networking):
    _icon = "front-door-and-cdn-profiles.png"


class IpAddressManager(_Networking):
    _icon = "ip-address-manager.png"


class IpGroups(_Networking):
    _icon = "ip-groups.png"


class LoadBalancerHub(_Networking):
    _icon = "load-balancer-hub.png"


class LoadBalancers(_Networking):
    _icon = "load-balancers.png"


class LocalNetworkGateways(_Networking):
    _icon = "local-network-gateways.png"


class Nat(_Networking):
    _icon = "nat.png"


class NetworkInterfaces(_Networking):
    _icon = "network-interfaces.png"


class NetworkSecurityGroups(_Networking):
    _icon = "network-security-groups.png"


class NetworkWatcher(_Networking):
    _icon = "network-watcher.png"


class OnPremisesDataGateways(_Networking):
    _icon = "on-premises-data-gateways.png"


class PrivateLinkService(_Networking):
    _icon = "private-link-service.png"


class PrivateLinkServices(_Networking):
    _icon = "private-link-services.png"


class PrivateLink(_Networking):
    _icon = "private-link.png"


class ProximityPlacementGroups(_Networking):
    _icon = "proximity-placement-groups.png"


class PublicIpAddressesClassic(_Networking):
    _icon = "public-ip-addresses-classic.png"


class PublicIpAddresses(_Networking):
    _icon = "public-ip-addresses.png"


class PublicIpPrefixes(_Networking):
    _icon = "public-ip-prefixes.png"


class ReservedIpAddressesClassic(_Networking):
    _icon = "reserved-ip-addresses-classic.png"


class ResourceManagementPrivateLink(_Networking):
    _icon = "resource-management-private-link.png"


class RouteFilters(_Networking):
    _icon = "route-filters.png"


class RouteTables(_Networking):
    _icon = "route-tables.png"


class ServiceEndpointPolicies(_Networking):
    _icon = "service-endpoint-policies.png"


class SpotVM(_Networking):
    _icon = "spot-vm.png"


class SpotVmss(_Networking):
    _icon = "spot-vmss.png"


class Subnet(_Networking):
    _icon = "subnet.png"


class TrafficController(_Networking):
    _icon = "traffic-controller.png"


class TrafficManagerProfiles(_Networking):
    _icon = "traffic-manager-profiles.png"


class VirtualNetworkGateways(_Networking):
    _icon = "virtual-network-gateways.png"


class VirtualNetworksClassic(_Networking):
    _icon = "virtual-networks-classic.png"


class VirtualNetworks(_Networking):
    _icon = "virtual-networks.png"


class VirtualRouter(_Networking):
    _icon = "virtual-router.png"


class VirtualWanHub(_Networking):
    _icon = "virtual-wan-hub.png"


class VirtualWans(_Networking):
    _icon = "virtual-wans.png"


class WebApplicationFirewallPolicieswaf(_Networking):
    _icon = "web-application-firewall-policieswaf.png"


# Aliases
