from . import _Azure


class _Devops(_Azure):
    _type = "devops"
    _icon_dir = "resource_images/azure/devops"


class APIConnections(_Devops):
    _icon = "api-connections.png"


class APIManagementServices(_Devops):
    _icon = "api-management-services.png"


class ApplicationInsights(_Devops):
    _icon = "application-insights.png"


class Artifacts(_Devops):
    _icon = "artifacts.png"


class AzureDevops(_Devops):
    _icon = "azure-devops.png"


class Boards(_Devops):
    _icon = "boards.png"


class ChangeAnalysis(_Devops):
    _icon = "change-analysis.png"


class Cloudtest(_Devops):
    _icon = "cloudtest.png"


class CodeOptimization(_Devops):
    _icon = "code-optimization.png"


class DevopsStarter(_Devops):
    _icon = "devops-starter.png"


class Devops(_Devops):
    _icon = "devops.png"


class DevtestLabs(_Devops):
    _icon = "devtest-labs.png"


class LabAccounts(_Devops):
    _icon = "lab-accounts.png"


class LabServices(_Devops):
    _icon = "lab-services.png"


class LoadTesting(_Devops):
    _icon = "load-testing.png"


class Pipelines(_Devops):
    _icon = "pipelines.png"


class Repos(_Devops):
    _icon = "repos.png"


class TestPlans(_Devops):
    _icon = "test-plans.png"


# Aliases

# Terraform aliases
azurerm_application_insights = ApplicationInsights
azurerm_devtest_lab = DevtestLabs
azurerm_devtest_virtual_network = DevtestLabs
