from . import _Azure


class _Managementgovernance(_Azure):
    _type = "managementgovernance"
    _icon_dir = "resource_images/azure/managementgovernance"


class ActivityLog(_Managementgovernance):
    _icon = "activity-log.png"


class Advisor(_Managementgovernance):
    _icon = "advisor.png"


class Alerts(_Managementgovernance):
    _icon = "alerts.png"


class ApplicationInsights(_Managementgovernance):
    _icon = "application-insights.png"


class ArcMachines(_Managementgovernance):
    _icon = "arc-machines.png"


class AutomationAccounts(_Managementgovernance):
    _icon = "automation-accounts.png"


class AzureArc(_Managementgovernance):
    _icon = "azure-arc.png"


class AzureLighthouse(_Managementgovernance):
    _icon = "azure-lighthouse.png"


class Blueprints(_Managementgovernance):
    _icon = "blueprints.png"


class Compliance(_Managementgovernance):
    _icon = "compliance.png"


class CostManagementAndBilling(_Managementgovernance):
    _icon = "cost-management-and-billing.png"


class CustomerLockboxForMicrosoftAzure(_Managementgovernance):
    _icon = "customer-lockbox-for-microsoft-azure.png"


class DiagnosticsSettings(_Managementgovernance):
    _icon = "diagnostics-settings.png"


class Education(_Managementgovernance):
    _icon = "education.png"


class IntuneTrends(_Managementgovernance):
    _icon = "intune-trends.png"


class LogAnalyticsWorkspaces(_Managementgovernance):
    _icon = "log-analytics-workspaces.png"


class Machinesazurearc(_Managementgovernance):
    _icon = "machinesazurearc.png"


class ManagedApplicationsCenter(_Managementgovernance):
    _icon = "managed-applications-center.png"


class ManagedDesktop(_Managementgovernance):
    _icon = "managed-desktop.png"


class Metrics(_Managementgovernance):
    _icon = "metrics.png"


class Monitor(_Managementgovernance):
    _icon = "monitor.png"


class MyCustomers(_Managementgovernance):
    _icon = "my-customers.png"


class OperationLogClassic(_Managementgovernance):
    _icon = "operation-log-classic.png"


class Policy(_Managementgovernance):
    _icon = "policy.png"


class RecoveryServicesVaults(_Managementgovernance):
    _icon = "recovery-services-vaults.png"


class ResourceGraphExplorer(_Managementgovernance):
    _icon = "resource-graph-explorer.png"


class ResourcesProvider(_Managementgovernance):
    _icon = "resources-provider.png"


class SchedulerJobCollections(_Managementgovernance):
    _icon = "scheduler-job-collections.png"


class ServiceCatalogMad(_Managementgovernance):
    _icon = "service-catalog-mad.png"


class ServiceProviders(_Managementgovernance):
    _icon = "service-providers.png"


class Solutions(_Managementgovernance):
    _icon = "solutions.png"


class UniversalPrint(_Managementgovernance):
    _icon = "universal-print.png"


class UserPrivacy(_Managementgovernance):
    _icon = "user-privacy.png"


# Aliases

# Terraform aliases
azurerm_monitor_action_group = Monitor
azurerm_monitor_activity_log_alert = ActivityLog
azurerm_log_analytics_workspace = LogAnalyticsWorkspaces
azurerm_application_insights = ApplicationInsights
azurerm_automation_account = AutomationAccounts
azurerm_policy_definition = Policy
azurerm_policy_assignment = Policy
azurerm_recovery_services_vault = RecoveryServicesVaults
