from . import _Azure


class _Hybridmulticloud(_Azure):
    _type = "hybridmulticloud"
    _icon_dir = "resource_images/azure/hybridmulticloud"


class AzureOperator5GCore(_Hybridmulticloud):
    _icon = "azure-operator-5g-core.png"


class AzureOperatorInsights(_Hybridmulticloud):
    _icon = "azure-operator-insights.png"


class AzureOperatorNexus(_Hybridmulticloud):
    _icon = "azure-operator-nexus.png"


class AzureOperatorServiceManager(_Hybridmulticloud):
    _icon = "azure-operator-service-manager.png"


class AzureProgrammableConnectivity(_Hybridmulticloud):
    _icon = "azure-programmable-connectivity.png"


# Aliases
