from . import _Azure


class _Aimachinelearning(_Azure):
    _type = "aimachinelearning"
    _icon_dir = "resource_images/azure/aimachinelearning"


class AIStudio(_Aimachinelearning):
    _icon = "ai-studio.png"


class AnomalyDetector(_Aimachinelearning):
    _icon = "anomaly-detector.png"


class AzureAppliedAIServices(_Aimachinelearning):
    _icon = "azure-applied-ai-services.png"


class AzureExperimentationStudio(_Aimachinelearning):
    _icon = "azure-experimentation-studio.png"


class AzureObjectUnderstanding(_Aimachinelearning):
    _icon = "azure-object-understanding.png"


class AzureOpenai(_Aimachinelearning):
    _icon = "azure-openai.png"


class BatchAI(_Aimachinelearning):
    _icon = "batch-ai.png"


class Bonsai(_Aimachinelearning):
    _icon = "bonsai.png"


class BotServices(_Aimachinelearning):
    _icon = "bot-services.png"


class CognitiveSearch(_Aimachinelearning):
    _icon = "cognitive-search.png"


class CognitiveServicesDecisions(_Aimachinelearning):
    _icon = "cognitive-services-decisions.png"


class CognitiveServices(_Aimachinelearning):
    _icon = "cognitive-services.png"


class ComputerVision(_Aimachinelearning):
    _icon = "computer-vision.png"


class ContentModerators(_Aimachinelearning):
    _icon = "content-moderators.png"


class CustomVision(_Aimachinelearning):
    _icon = "custom-vision.png"


class FaceApis(_Aimachinelearning):
    _icon = "face-apis.png"


class FormRecognizers(_Aimachinelearning):
    _icon = "form-recognizers.png"


class GenomicsAccounts(_Aimachinelearning):
    _icon = "genomics-accounts.png"


class Genomics(_Aimachinelearning):
    _icon = "genomics.png"


class ImmersiveReaders(_Aimachinelearning):
    _icon = "immersive-readers.png"


class LanguageUnderstanding(_Aimachinelearning):
    _icon = "language-understanding.png"


class Language(_Aimachinelearning):
    _icon = "language.png"


class MachineLearningStudioClassicWebServices(_Aimachinelearning):
    _icon = "machine-learning-studio-classic-web-services.png"


class MachineLearningStudioWebServicePlans(_Aimachinelearning):
    _icon = "machine-learning-studio-web-service-plans.png"


class MachineLearningStudioWorkspaces(_Aimachinelearning):
    _icon = "machine-learning-studio-workspaces.png"


class MachineLearning(_Aimachinelearning):
    _icon = "machine-learning.png"


class MetricsAdvisor(_Aimachinelearning):
    _icon = "metrics-advisor.png"


class Personalizers(_Aimachinelearning):
    _icon = "personalizers.png"


class QnaMakers(_Aimachinelearning):
    _icon = "qna-makers.png"


class ServerlessSearch(_Aimachinelearning):
    _icon = "serverless-search.png"


class SpeechServices(_Aimachinelearning):
    _icon = "speech-services.png"


class TranslatorText(_Aimachinelearning):
    _icon = "translator-text.png"


# Aliases

# Terraform aliases
azurerm_cognitive_account = CognitiveServices
azurerm_search_service = CognitiveSearch
azurerm_bot_service_azure_bot = BotServices
azurerm_machine_learning_workspace = MachineLearning
