from . import _Azure


class _Web(_Azure):
    _type = "web"
    _icon_dir = "resource_images/azure/web"


class APICenter(_Web):
    _icon = "api-center.png"


class APIConnections(_Web):
    _icon = "api-connections.png"


class APIManagementServices(_Web):
    _icon = "api-management-services.png"


class AppServiceCertificates(_Web):
    _icon = "app-service-certificates.png"


class AppServiceDomains(_Web):
    _icon = "app-service-domains.png"


class AppServiceEnvironments(_Web):
    _icon = "app-service-environments.png"


class AppServicePlans(_Web):
    _icon = "app-service-plans.png"


class AppServices(_Web):
    _icon = "app-services.png"


class AppSpace(_Web):
    _icon = "app-space.png"


class AzureMediaService(_Web):
    _icon = "azure-media-service.png"


class AzureSpringApps(_Web):
    _icon = "azure-spring-apps.png"


class CognitiveSearch(_Web):
    _icon = "cognitive-search.png"


class CognitiveServices(_Web):
    _icon = "cognitive-services.png"


class FrontDoorAndCDNProfiles(_Web):
    _icon = "front-door-and-cdn-profiles.png"


class MediaServices(_Web):
    _icon = "media-services.png"


class NotificationHubNamespaces(_Web):
    _icon = "notification-hub-namespaces.png"


class PowerPlatform(_Web):
    _icon = "power-platform.png"


class Search(_Web):
    _icon = "search.png"


class Signalr(_Web):
    _icon = "signalr.png"


class StaticApps(_Web):
    _icon = "static-apps.png"


# Aliases

# Terraform aliases
azurerm_api_management = APIManagementServices
azurerm_app_service = AppServices
azurerm_app_service_plan = AppServicePlans
azurerm_service_plan = AppServicePlans
azurerm_app_service_certificate = AppServiceCertificates
azurerm_app_service_environment = AppServiceEnvironments
azurerm_media_services_account = MediaServices
azurerm_search_service = Search
azurerm_signalr_service = Signalr
azurerm_static_site = StaticApps
