from . import _Azure


class _Iot(_Azure):
    _type = "iot"
    _icon_dir = "resource_images/azure/iot"


class AzureCosmosDb(_Iot):
    _icon = "azure-cosmos-db.png"


class AzureDataboxGateway(_Iot):
    _icon = "azure-databox-gateway.png"


class AzureIotOperations(_Iot):
    _icon = "azure-iot-operations.png"


class AzureMapsAccounts(_Iot):
    _icon = "azure-maps-accounts.png"


class AzureStack(_Iot):
    _icon = "azure-stack.png"


class DeviceProvisioningServices(_Iot):
    _icon = "device-provisioning-services.png"


class DigitalTwins(_Iot):
    _icon = "digital-twins.png"


class EventGridSubscriptions(_Iot):
    _icon = "event-grid-subscriptions.png"


class EventHubClusters(_Iot):
    _icon = "event-hub-clusters.png"


class EventHubs(_Iot):
    _icon = "event-hubs.png"


class FunctionApps(_Iot):
    _icon = "function-apps.png"


class IndustrialIot(_Iot):
    _icon = "industrial-iot.png"


class IotCentralApplications(_Iot):
    _icon = "iot-central-applications.png"


class IotEdge(_Iot):
    _icon = "iot-edge.png"


class IotHubSecurity(_Iot):
    _icon = "iot-hub-security.png"


class IotHub(_Iot):
    _icon = "iot-hub.png"


class LogicApps(_Iot):
    _icon = "logic-apps.png"


class MachineLearningStudioClassicWebServices(_Iot):
    _icon = "machine-learning-studio-classic-web-services.png"


class MachineLearningStudioWebServicePlans(_Iot):
    _icon = "machine-learning-studio-web-service-plans.png"


class MachineLearningStudioWorkspaces(_Iot):
    _icon = "machine-learning-studio-workspaces.png"


class Maps(_Iot):
    _icon = "maps.png"


class NotificationHubNamespaces(_Iot):
    _icon = "notification-hub-namespaces.png"


class NotificationHubs(_Iot):
    _icon = "notification-hubs.png"


class Sphere(_Iot):
    _icon = "sphere.png"


class StackHciPremium(_Iot):
    _icon = "stack-hci-premium.png"


class StreamAnalyticsJobs(_Iot):
    _icon = "stream-analytics-jobs.png"


class TimeSeriesDataSets(_Iot):
    _icon = "time-series-data-sets.png"


class TimeSeriesInsightsAccessPolicies(_Iot):
    _icon = "time-series-insights-access-policies.png"


class TimeSeriesInsightsEnvironments(_Iot):
    _icon = "time-series-insights-environments.png"


class TimeSeriesInsightsEventSources(_Iot):
    _icon = "time-series-insights-event-sources.png"


class TimeSeriesInsightsEventsSources(_Iot):
    _icon = "time-series-insights-events-sources.png"


class Windows10IotCoreServices(_Iot):
    _icon = "windows-10-iot-core-services.png"


class Windows10CoreServices(_Iot):
    _icon = "windows10-core-services.png"


# Aliases

# Terraform aliases
azurerm_cosmosdb_account = AzureCosmosDb
azurerm_maps_account = AzureMapsAccounts
azurerm_iothub_dps = DeviceProvisioningServices
azurerm_digital_twins_instance = DigitalTwins
azurerm_eventgrid_event_subscription = EventGridSubscriptions
azurerm_eventhub_namespace = EventHubs
azurerm_eventhub = EventHubs
azurerm_function_app = FunctionApps
azurerm_iotcentral_application = IotCentralApplications
azurerm_iothub = IotHub
azurerm_logic_app_workflow = LogicApps
azurerm_notification_hub_namespace = NotificationHubNamespaces
azurerm_notification_hub = NotificationHubs
azurerm_stream_analytics_job = StreamAnalyticsJobs
