from . import _GCP


class _Management(_GCP):
    _type = "management"
    _icon_dir = "resources/gcp/management"


class Billing(_Management):
    _icon = "billing.png"


class Project(_Management):
    _icon = "project.png"


class Quotas(_Management):
    _icon = "quotas.png"


class Support(_Management):
    _icon = "support.png"


# Aliases

# Terraform aliases
google_project = Project
google_billing_account = Billing
