from . import _Azure


class _Storage(_Azure):
    _type = "storage"
    _icon_dir = "resource_images/azure/storage"


class ArchiveStorage(_Storage):
    _icon = "archive-storage.png"


class AzureDataboxGateway(_Storage):
    _icon = "azure-databox-gateway.png"


class AzureFileshares(_Storage):
    _icon = "azure-fileshares.png"


class AzureHcpCache(_Storage):
    _icon = "azure-hcp-cache.png"


class AzureNetappFiles(_Storage):
    _icon = "azure-netapp-files.png"


class AzureStackEdge(_Storage):
    _icon = "azure-stack-edge.png"


class Azurefxtedgefiler(_Storage):
    _icon = "azurefxtedgefiler.png"


class BlobStorage(_Storage):
    _icon = "blob-storage.png"


class DataBoxEdgeDataBoxGateway(_Storage):
    _icon = "data-box-edge-data-box-gateway.png"


class DataBox(_Storage):
    _icon = "data-box.png"


class DataLakeStorageGen1(_Storage):
    _icon = "data-lake-storage-gen1.png"


class DataLakeStorage(_Storage):
    _icon = "data-lake-storage.png"


class DataShareInvitations(_Storage):
    _icon = "data-share-invitations.png"


class DataShares(_Storage):
    _icon = "data-shares.png"


class GeneralStorage(_Storage):
    _icon = "general-storage.png"


class ImportExportJobs(_Storage):
    _icon = "import-export-jobs.png"


class NetappFiles(_Storage):
    _icon = "netapp-files.png"


class QueuesStorage(_Storage):
    _icon = "queues-storage.png"


class RecoveryServicesVaults(_Storage):
    _icon = "recovery-services-vaults.png"


class StorageAccountsClassic(_Storage):
    _icon = "storage-accounts-classic.png"


class StorageAccounts(_Storage):
    _icon = "storage-accounts.png"


class StorageExplorer(_Storage):
    _icon = "storage-explorer.png"


class StorageSyncServices(_Storage):
    _icon = "storage-sync-services.png"


class StorsimpleDataManagers(_Storage):
    _icon = "storsimple-data-managers.png"


class StorsimpleDeviceManagers(_Storage):
    _icon = "storsimple-device-managers.png"


class TableStorage(_Storage):
    _icon = "table-storage.png"


# Aliases

# Terraform aliases
azurerm_storage_account = StorageAccounts
azurerm_storage_blob = BlobStorage
azurerm_storage_container = BlobStorage
azurerm_storage_share = AzureFileshares
azurerm_storage_queue = QueuesStorage
azurerm_storage_table = TableStorage
azurerm_data_lake_store = DataLakeStorage
azurerm_netapp_account = NetappFiles
azurerm_netapp_volume = NetappFiles
azurerm_recovery_services_vault = RecoveryServicesVaults
azurerm_backup_vault = RecoveryServicesVaults
azurerm_storage_sync = StorageSyncServices
